/** @jsx jsx */
import { jsx, css } from '@emotion/core';
import * as React from 'react';
import {
  Text,
  useTheme,
  Navbar,
  Toolbar,
  InputGroup,
  Input,
  Popover,
  MenuList,
  MenuItem,
  MenuDivider,
  Button,
  Avatar,
  IconChevronDown,
} from 'sancho';
import useThemeMode from '../hooks/useThemeMode';
import { navigate } from '@reach/router';

const Nav: React.FC = () => {
  const { isLightTheme } = useThemeMode();
  const theme = useTheme();
  return (
    <Navbar
      position="fixed"
      css={css`
        width: calc(100% - 14rem);
        left: auto;
        box-shadow: none;
        border-bottom: 1px solid
          ${isLightTheme
            ? theme.colors.border.default
            : theme.colors.palette.gray.base};
      `}
    >
      <Toolbar>
        <div
          css={css`
            min-height: 64px;
            display: flex;
            position: relative;
            align-items: center;
          `}
        >
          <Text
            variant="h5"
            css={css`
              margin: 0;
            `}
          >
            Dashboard
          </Text>
        </div>
        <div
          css={css`
            width: 250px;
            margin-left: auto;
            flex: 0 0 auto;
          `}
        >
          <form>
            <InputGroup label="Search" hideLabel>
              <Input placeholder="Search..." />
            </InputGroup>
          </form>
        </div>
        <div
          css={css`
            margin-left: 1rem;
          `}
        >
          <Popover
            content={
              <MenuList>
                <MenuItem onPress={() => navigate('/account/profile')}>
                  Account
                </MenuItem>
                <MenuItem>Get help</MenuItem>
                <MenuDivider />
                <MenuItem>Log out</MenuItem>
              </MenuList>
            }
          >
            <Button variant="ghost" iconAfter={<IconChevronDown />}>
              <Avatar size="sm" name="Felix Leighter" />
            </Button>
          </Popover>
        </div>
      </Toolbar>
    </Navbar>
  );
};

export default Nav;
