/** @jsx jsx */
import { jsx, css } from '@emotion/core';
import * as React from 'react';
import { Link } from '@reach/router';
import { IconButton, IconSun, Text, useTheme, Divider } from 'sancho';
import useThemeMode from '../hooks/useThemeMode';

const Sidebar: React.FC = () => {
  const { setThemeMode, isLightTheme } = useThemeMode();
  const theme = useTheme();
  return (
    <aside
      css={css`
        display: block;
        position: sticky;
        top: 0;
        height: 100vh;
        background: ${isLightTheme
          ? theme.colors.background.tint1
          : theme.colors.scales.gray[8]};
      `}
    >
      <div
        css={css`
          height: 100%;
          display: flex;
          flex-direction: column;
          width: 14rem;
        `}
      >
        <div
          css={css`
            height: 64px;
            border-bottom: 1px solid
              ${isLightTheme
                ? theme.colors.border.default
                : theme.colors.scales.gray[7]};
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding-left: 1.5rem;
            padding-right: 1rem;
          `}
        >
          <Link
            to="/"
            css={css`
              text-decoration: none;
            `}
          >
            <Text
              variant="h5"
              css={css`
                margin: 0;
                color: ${theme.colors.intent.primary.light};
              `}
            >
              High Output
            </Text>
          </Link>
          <IconButton
            onClick={() => setThemeMode(isLightTheme ? 'dark' : 'light')}
            icon={<IconSun />}
            label="Menu"
            variant="ghost"
          />
        </div>
        <div>
          <div
            css={css`
              margin: 1rem 0;
            `}
          >
            <ul
              css={css`
                padding: 0;
                margin: 0;
              `}
            >
              <li
                css={css`
                  list-style: none;
                  padding-left: 0;
                  margin-bottom: 0;
                `}
              >
                <Text
                  css={css`
                    padding: 0.25rem 1.5rem;
                  `}
                  variant="uppercase"
                >
                  Manage
                </Text>
                <Link
                  to="/dashboard"
                  css={css`
                    display: block;
                    color: ${isLightTheme
                      ? theme.colors.intent.none.light
                      : theme.colors.intent.none.dark};
                    padding: 0.25rem 1.5rem;
                    text-decoration: none;
                    &:hover {
                      background-color: ${isLightTheme
                        ? theme.colors.scales.gray[3]
                        : theme.colors.scales.gray[7]};
                    }
                  `}
                >
                  <Text
                    css={css`
                      font-size: 0.875rem;
                    `}
                  >
                    Dashboard
                  </Text>
                </Link>
              </li>
            </ul>
          </div>
          <Divider />
          <div
            css={css`
              margin: 1rem 0;
            `}
          >
            <ul
              css={css`
                padding: 0;
                margin: 0;
              `}
            >
              <li
                css={css`
                  list-style: none;
                  padding-left: 0;
                  margin-bottom: 0;
                `}
              >
                <Text
                  css={css`
                    padding: 0.25rem 1.5rem;
                  `}
                  variant="uppercase"
                >
                  Account
                </Text>
                <Link
                  to="/account/profile"
                  css={css`
                    display: block;
                    color: ${isLightTheme
                      ? theme.colors.intent.none.light
                      : theme.colors.intent.none.dark};
                    padding: 0.25rem 1.5rem;
                    text-decoration: none;
                    &:hover {
                      background-color: ${isLightTheme
                        ? theme.colors.scales.gray[3]
                        : theme.colors.scales.gray[7]};
                    }
                  `}
                >
                  <Text
                    css={css`
                      font-size: 0.875rem;
                    `}
                  >
                    Profile
                  </Text>
                </Link>
              </li>
            </ul>
          </div>
        </div>
      </div>
    </aside>
  );
};

export default Sidebar;
