import * as React from 'react';
import { useQuery } from 'react-apollo-hooks';
import gql from 'graphql-tag';
import { get } from 'lodash';
import useEventListener from '@use-it/event-listener';

const ME = gql`
  query me {
    me {
      id
      username
      email
      firstname
      lastname
      gender
      mobilePhone
      wechat
      qqnumber
      currency
      language
      role
      nickname
      dateTimeCreated
      ... on Member {
        totalBalance
        availableBalance
        bankAccount {
          id
          bank
          accountName
          accountNumber
          province
          country
          city
          branch
        }
      }
    }
  }
`;

const AccountContext = React.createContext({
  account: null,
});

export const AccountProvider = ({ children }: React.PropsWithChildren<{}>) => {
  const [accessToken, setAccessToken] = React.useState(
    localStorage.getItem('accessToken')
  );

  useEventListener('storage', ({ key, newValue }: any) => {
    if (key === 'accessToken') {
      setAccessToken(newValue);
    }
  });

  const { data, error, loading, refetch } = useQuery(ME, {
    skip: !accessToken,
  });

  React.useEffect(() => {
    refetch();
  }, [accessToken]);

  if (loading) {
    return <div>Loading...</div>;
  }
  if (error) {
    return <div>Error! {error.message}</div>;
  }
  return (
    <AccountContext.Provider value={{ account: get(data, 'me') }}>
      {children}
    </AccountContext.Provider>
  );
};

export const useAccountValue = () => React.useContext(AccountContext);
