/** @jsx jsx */
import { jsx, css } from '@emotion/core';
import * as React from 'react';
import { Text, Layer, useTheme, Button, useToast } from 'sancho';
import { RouteComponentProps } from '@reach/router';

const Profile: React.FC<RouteComponentProps> = () => {
  const theme = useTheme();
  const toast = useToast();
  return (
    <div>
      <Layer
        elevation="sm"
        css={css`
          box-shadow: none;
          border-radius: 0.25rem;
          border: 2px solid ${theme.colors.border.muted};
          padding: 2rem;
        `}
      >
        <div
          css={css`
            margin-bottom: 0.5rem;
            display: flex;
          `}
        >
          <Text variant="h2">Use Google for Login</Text>
          <Button
            css={css`
              margin-left: auto;
            `}
            onClick={() => {
              toast({
                title: 'My primary message for the user.',
                duration: 5000,
                subtitle: 'Details to report to the user.',
              });
            }}
          >
            Use Google SSO
          </Button>
        </div>
        <Text
          variant="paragraph"
          css={css`
            margin: 0;
          `}
        >
          Google offers a solution that reduces the number of logins required to
          access your web apps: Single Sign On (SSO). Users login with their
          Google credentials, then access third-party applications. No need for
          an additional username or password. SSO reduces the number of
          passwords people need to manage.
        </Text>
      </Layer>
    </div>
  );
};

export default Profile;
