/** @jsx jsx */
import { jsx, css } from '@emotion/core';
import * as React from 'react';
import { RouteComponentProps, Link } from '@reach/router';
import { Text, Layer, InputGroup, Input, Button } from 'sancho';
import { Redirect } from '@reach/router';
import * as Yup from 'yup';
import { Formik } from 'formik';

import { useAccountValue } from '../../hooks/useAccount';

const Login: React.FC<RouteComponentProps> = () => {
  const { account } = useAccountValue();
  if (account) return <Redirect to="/dashboard" noThrow />;
  return (
    <Layer
      elevation="xs"
      css={css`
        max-width: 450px;
        margin: 5rem auto 0;
        padding: 2rem;
      `}
    >
      <Text
        variant="h1"
        css={css`
          text-align: center;
          margin-bottom: 2rem;
        `}
      >
        Sign in
      </Text>
      <div
        css={css`
          margin-bottom: 1rem;
        `}
      >
        <Formik
          initialValues={{ username: '', password: '' }}
          onSubmit={(values, { setSubmitting }) => {
            console.log(values);
            setSubmitting(false);
          }}
          validationSchema={Yup.object().shape({
            username: Yup.string().required('Required'),
            password: Yup.string().required('Required'),
          })}
        >
          {props => {
            const {
              values,
              errors,
              isSubmitting,
              handleChange,
              handleBlur,
              handleSubmit,
            } = props;
            return (
              <form onSubmit={handleSubmit}>
                <InputGroup
                  label="Email"
                  css={css`
                    margin-bottom: 1rem;
                  `}
                >
                  <Input
                    type="text"
                    name="username"
                    value={values.username}
                    placeholder="john"
                    onChange={handleChange}
                    onBlur={handleBlur}
                  />
                </InputGroup>
                <InputGroup
                  label="Password"
                  css={css`
                    margin-bottom: 1rem;
                  `}
                >
                  <Input
                    type="password"
                    name="password"
                    value={values.password}
                    placeholder="password"
                    onChange={handleChange}
                    onBlur={handleBlur}
                  />
                </InputGroup>
                <Button
                  component="button"
                  intent="primary"
                  type="submit"
                  block
                  disabled={isSubmitting}
                >
                  Sign in
                </Button>
              </form>
            );
          }}
        </Formik>
      </div>
      <Text
        variant="subtitle"
        css={css`
          text-align: center;
        `}
      >
        Don’t have an account? <Link to="/register">Sign up</Link>
      </Text>
    </Layer>
  );
};

export default Login;
