/** @jsx jsx */
import { jsx, css } from '@emotion/core';
import * as React from 'react';
import { RouteComponentProps, Link, Redirect, navigate } from '@reach/router';
import { Text, Layer, InputGroup, Input, Button } from 'sancho';
import * as Yup from 'yup';
import { Formik } from 'formik';
import gql from 'graphql-tag';
import { useMutation } from 'react-apollo-hooks';

import { useAccountValue } from '../../hooks/useAccount';

const CREATE_MEMBER = gql`
  mutation createMember($input: CreateMemberInput) {
    createMember(input: $input)
  }
`;

const Register: React.FC<RouteComponentProps> = () => {
  const { account } = useAccountValue();

  const createMember = useMutation(CREATE_MEMBER, {});

  if (account) return <Redirect to="/dashboard" noThrow />;
  return (
    <Layer
      elevation="xs"
      css={css`
        max-width: 450px;
        margin: 5rem auto 0;
        padding: 2rem;
      `}
    >
      <Text
        variant="h1"
        css={css`
          text-align: center;
          margin-bottom: 2rem;
        `}
      >
        Create new account
      </Text>
      <div
        css={css`
          margin-bottom: 1rem;
        `}
      >
        <Formik
          initialValues={{ username: '', password: '' }}
          onSubmit={async (values, actions) => {
            createMember({
              variables: {
                input: values,
              },
            })
              .then(async result => {
                await localStorage.setItem(
                  'accessToken',
                  result.data.createMember
                );
                actions.resetForm();
                actions.setSubmitting(false);
                navigate('/dashboard');
              })
              .catch(error => {
                console.log('\n\n error', error);
                actions.resetForm();
                actions.setSubmitting(false);
              });
          }}
          validationSchema={Yup.object().shape({
            username: Yup.string().required('Required'),
            password: Yup.string().required('Required'),
          })}
        >
          {props => {
            const {
              values,
              errors,
              isSubmitting,
              handleChange,
              handleBlur,
              handleSubmit,
            } = props;
            return (
              <form onSubmit={handleSubmit}>
                <InputGroup
                  label="Email address"
                  css={css`
                    margin-bottom: 1rem;
                  `}
                >
                  <Input
                    name="username"
                    value={values.username}
                    placeholder="john"
                    onChange={handleChange}
                    onBlur={handleBlur}
                  />
                </InputGroup>
                <InputGroup
                  label="Password"
                  css={css`
                    margin-bottom: 1rem;
                  `}
                >
                  <Input
                    type="password"
                    name="password"
                    value={values.password}
                    placeholder="password"
                    onChange={handleChange}
                    onBlur={handleBlur}
                  />
                </InputGroup>
                <Button
                  component="button"
                  intent="primary"
                  type="submit"
                  block
                  disabled={isSubmitting}
                >
                  Create account
                </Button>
              </form>
            );
          }}
        </Formik>
      </div>
      <Text
        variant="subtitle"
        css={css`
          text-align: center;
          margin-bottom: 1rem;
        `}
      >
        By signing up, you agreed to our{' '}
        <Link to="#target">User Terms of Service</Link> and <br />
        <Link to="#target">Privacy Policy</Link>.
      </Text>
      <Text
        variant="subtitle"
        css={css`
          text-align: center;
        `}
      >
        Already have an account? <Link to="/login">Sign in</Link>
      </Text>
    </Layer>
  );
};

export default Register;
